#!/bin/sh
#*******************************************************************************
# Licensed Materials - Property of IBM
# (c) Copyright IBM Corporation 2012, 2013. All Rights Reserved.
#
# Note to U.S. Government Users Restricted Rights:
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp.
#*******************************************************************************
# genlink.sh
#   This shellscript is used to inspect existing IBM i *PGM and *SRVPGM objects
#   to find the module and service program bindings and generate source members
#   based on these bindings.
#
#   This shellscript is to be run in IBM i's QSH interpreter.
#
# Example of Usage
#   genlink.sh -inlib=MYPGMLIB -objName=MYPGM -outFs=qsys -outLib=MYSRCLIB -objType=*PGM -workLib=MYTEMPLIB
#
#  Parameters:
#      -inLib=LIBNAME, where LIBNAME is a library containing *PGMs or *SRVPGMs which
#               are to be inspected for their bindings
#      -inObj={*ALL | PGMNAME}, where PGMNAME is an absolute or generic object name
#               of the object(s) in -inLib to generate bindings for. *ALL means all objects in -inLib.
#      -outFs={qsys | ifs}
#            If qsys, *PGM bindings are written to source file QPGMSRC, member *PGM-name, type PGMSRC.
#                     *SRVPGM bindings are written to source file QSRVPGMSRC, member *SRVPGM-name, type PGMSRC.
#            IF ifs, *PGM and *SRVPGM bindings are written to the -outDir directory,
#                     with .PGMSRC and .SRVPGMSRC extensions, respectively.
#      -outLib=LIBNAME, where LIBNAME is a library to contain generated source files QPGMSRC or QSRVPGMSRC
#      -objType={*pgm | *srvpgm}
#            If *PGM, look for *PGMs to generate PGMSRC for
#            If *SRVPGM, look for *SRVPGMs to generate SRVPGMSRC for
#      -workLib=LIBNAME, where LIBNAME is a working library to contain temporary outputs (e.g. *USRSPC) while inspecting
#            objects from the inLib.
#      -replRefLib={libl,objlib,keep}: Replace referenced library
#            keep=keep bound library names hardcoded as they were found in the existing *PGMs/*SRVPGMs
#            libl=replace bound library names with *LIBL as searchpath
#            objlib=replace bound library names with &OBJLIB variable name.
#      -outDir=IFS_DIR, where IFS_DIR is an IFS directory to write the contents (only if -outFs=ifs)
export JAVA_HOME=/QOpenSys/QIBM/ProdData/JavaVM/jdk60/32bit
# Note: BUILDSYSTEM needs to be updated per release (when RTCxxx changes)
export BUILDSYSTEM=/QIBM/ProdData/RTC405/Build/jazz/buildsystem
export TOOLKIT_HOME=$BUILDSYSTEM/buildtoolkit
# Notes: TOOLKIT_JAR needs to be updated when the toolkit jar is updated;
#        Similarly JT400 needs to be updated when jt400.jar is updated and NLS_JAR needs ot be updated when OSGI is updated
export TOOLKIT_JAR=$TOOLKIT_HOME/com.ibm.teamp.build.toolkit_3.1.700.v20130916_2046.jar
export NLS_JAR=$TOOLKIT_HOME/org.eclipse.osgi_3.6.50.R36x_v20120315-1500.jar
export JT400=$BUILDSYSTEM/buildengine/eclipse/plugins/com.ibm.etools.iseries.toolbox_8.5.1.v20121025_2130/runtime/jt400.jar

export CP=$TOOLKIT_JAR:$JT400:$NLS_JAR

export MAINCLASS=com.ibm.teami.build.toolkit.genlink.cli.MainCli

exec $JAVA_HOME/bin/java -cp $CP com.ibm.teami.build.toolkit.genlink.cli.MainCli "$@"

